Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/phpmyadmin/phpmyadmin.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMaurício Meneghini Fauth <mauricio@fauth.dev>2020-09-02 16:57:57 +0300
committerMaurício Meneghini Fauth <mauricio@fauth.dev>2020-09-02 16:57:57 +0300
commitceac762e0908da49f0f01b100d2469ec9d12d162 (patch)
tree73e9bf1bba23166825751a35f5e35483f32e7c2d /libraries/classes/Tracking.php
parente24a285f5a9f3a3c0627b40abc3670f01f9b8030 (diff)
Remove pmaThemePath and pmaThemeImage PHP globals
Signed-off-by: Maurício Meneghini Fauth <mauricio@fauth.dev>
Diffstat (limited to 'libraries/classes/Tracking.php')
-rw-r--r--libraries/classes/Tracking.php24
1 files changed, 12 insertions, 12 deletions
diff --git a/libraries/classes/Tracking.php b/libraries/classes/Tracking.php
index d379584bef..d3d23e6e7d 100644
--- a/libraries/classes/Tracking.php
+++ b/libraries/classes/Tracking.php
@@ -142,16 +142,16 @@ class Tracking
/**
* Function to get html for main page parts that do not use $_REQUEST
*
* @param array $urlParams url parameters
* @param string $pmaThemeImage path to theme's image folder
* @param string $textDir text direction
* @param int $lastVersion last tracking version
*
* @return string
*/
public function getHtmlForMainPage(
$urlParams,
- $pmaThemeImage,
+ $themeImagePath,
$textDir,
$lastVersion = null
) {
@@ -190,7 +190,7 @@ class Tracking
'versions' => $versions,
'type' => $type,
'default_statements' => $GLOBALS['cfg']['Server']['tracking_default_statements'],
- 'pmaThemeImage' => $pmaThemeImage,
+ 'theme_image_path' => $themeImagePath,
'text_dir' => $textDir,
]);
}
@@ -1152,17 +1152,17 @@ class Tracking
/**
* Get HTML for tracked and untracked tables
*
* @param string $db current database
* @param array $urlParams url parameters
* @param string $pmaThemeImage path to theme's image folder
* @param string $textDir text direction
*
* @return string HTML
*/
public function getHtmlForDbTrackingTables(
string $db,
array $urlParams,
- string $pmaThemeImage,
+ string $themeImagePath,
string $textDir
) {
$relation = $this->relation;
@@ -1214,7 +1214,7 @@ class Tracking
'url_params' => $urlParams,
'text_dir' => $textDir,
'untracked_tables' => $untrackedTables,
- 'pma_theme_image' => $pmaThemeImage,
+ 'theme_image_path' => $themeImagePath,
]);
}
@@ -142,16 +142,16 @@ class Tracking
* Function to get html for main page parts that do not use $_REQUEST
*
- * @param array $urlParams url parameters
- * @param string $pmaThemeImage path to theme's image folder
- * @param string $textDir text direction
- * @param int $lastVersion last tracking version
+ * @param array $urlParams url parameters
+ * @param string $themeImagePath path to theme's image folder
+ * @param string $textDir text direction
+ * @param int $lastVersion last tracking version
*
* @return string
@@ -1152,17 +1152,17 @@ class Tracking
* Get HTML for tracked and untracked tables
*
- * @param string $db current database
- * @param array $urlParams url parameters
- * @param string $pmaThemeImage path to theme's image folder
- * @param string $textDir text direction
+ * @param string $db current database
+ * @param array $urlParams url parameters
+ * @param string $themeImagePath path to theme's image folder
+ * @param string $textDir text direction
*
* @return string HTML